==> order-center-api-2.0.9-CLOUD-UAT-20220609.045154-2-sources.jar: com/tydic/dyc/oc/service/domainservice/bo/UocShipOrderArrivaConfirmOrRefuseReqBo.java <==
package com.tydic.dyc.oc.service.domainservice.bo;

import com.tydic.dyc.base.bo.BaseUmcReqBo;
import com.tydic.dyc.oc.service.common.bo.UocBaseExtParallelDeleteBo;
import com.tydic.dyc.oc.service.common.bo.UocBaseExtParallelEditBo;
import com.tydic.dyc.oc.service.common.bo.UocBaseOrderAccessoryAddBo;
import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.util.Date;
import java.util.List;

/**
 * 标题:UocShipOrderArrivaConfirmOrRefuseReqBo
 * 说明:发货/拒收 入参
 * 时间:2022/2/24 11:21
 * 作者:罗有
 */

@EqualsAndHashCode(callSuper = true)
@Data
public class UocShipOrderArrivaConfirmOrRefuseReqBo extends BaseUmcReqBo {
    private static final long serialVersionUID = 3398938446971992877L;

    @DocField(value = "操作 1 到货确认 2到货拒收", required = true)
    private Integer opFlag;

    @DocField(value = "发货单ids", required = true)
    private List<Long> shipOrderIdList;

    @DocField(value = "订单id", required = true)
    private Long orderId;

    @DocField(value = "销售单id", required = true)
    private Long saleOrderId;

    @DocField(value = "收货人")
    private String receiverUser;

    @DocField(value = "收货备注")
    private String receiverRemark;

    @DocField(value = "收货联系电话")
    private String receiverContact;

    @DocField(value = "收货时间")
    private Date receiverTime;

    @DocField(value = "纵向扩展数据 更新")
    private List<UocBaseExtParallelEditBo> extEditList;

    @DocField(value = "纵向拓展信息 删除")
    private List<UocBaseExtParallelDeleteBo> extDeleteList;

    @DocField(value = "附件")
    private List<UocBaseOrderAccessoryAddBo> orderAccessoryBoList;
}

==> order-center-api-2.1.0-CLOUD-UAT-20220830.131257-1-sources.jar: com/tydic/dyc/oc/service/domainservice/bo/UocShipOrderArrivaConfirmOrRefuseReqBo.java <==
package com.tydic.dyc.oc.service.domainservice.bo;

import com.tydic.dyc.base.bo.BaseUmcReqBo;
import com.tydic.dyc.oc.service.common.bo.UocBaseExtParallelDeleteBo;
import com.tydic.dyc.oc.service.common.bo.UocBaseExtParallelEditBo;
import com.tydic.dyc.oc.service.common.bo.UocBaseOrderAccessoryAddBo;
import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;
import lombok.EqualsAndHashCode;

import java.util.Date;
import java.util.List;

/**
 * 标题:UocShipOrderArrivaConfirmOrRefuseReqBo
 * 说明:发货/拒收 入参
 * 时间:2022/2/24 11:21
 * 作者:罗有
 */

@EqualsAndHashCode(callSuper = true)
@Data
public class UocShipOrderArrivaConfirmOrRefuseReqBo extends BaseUmcReqBo {
    private static final long serialVersionUID = 3398938446971992877L;

    @DocField(value = "操作 1 到货确认 2到货拒收", required = true)
    private Integer opFlag;

    @DocField(value = "发货单ids", required = true)
    private List<Long> shipOrderIdList;

    @DocField(value = "订单id", required = true)
    private Long orderId;

    @DocField(value = "销售单id", required = true)
    private Long saleOrderId;

    @DocField(value = "收货人")
    private String receiverUser;

    @DocField(value = "收货备注")
    private String receiverRemark;

    @DocField(value = "收货联系电话")
    private String receiverContact;

    @DocField(value = "收货时间")
    private Date receiverTime;

    @DocField(value = "纵向扩展数据 更新")
    private List<UocBaseExtParallelEditBo> extEditList;

    @DocField(value = "纵向拓展信息 删除")
    private List<UocBaseExtParallelDeleteBo> extDeleteList;

    @DocField(value = "附件")
    private List<UocBaseOrderAccessoryAddBo> orderAccessoryBoList;

    @DocField(value = "任务id")
    private String taskId;

    @DocField(value = "任务id")
    private List<String> taskIds;
}
